@@ -238,10 +238,9 @@ class GasOil(object):
             dframe = dframe.reset_index()
 
         if sgcolname not in dframe:
-            logger.critical(
-                "%s not found in dataframe, can't read table data", sgcolname
+            raise ValueError(
+                f"{sgcolname} not found in dataframe, can't read table data"
             )
-            raise ValueError
 
         for col in [sgcolname, krgcolname, krogcolname, pccolname]:
             # Typecheck/convert all numerical columns:
@@ -250,16 +249,10 @@ class GasOil(object):
                 try:
                     dframe[col] = dframe[col].astype(float)
                     logger.info("Converted column %s to numbers for fromtable()", col)
-                except ValueError as e_msg:
-                    logger.error(
-                        "Failed to parse column %s as numbers for add_fromtable()", col
-                    )
-                    raise ValueError(e_msg)
-                except TypeError as e_msg:
-                    logger.error(
-                        "Failed to parse column %s as numbers for add_fromtable()", col
-                    )
-                    raise TypeError(e_msg)
+                except (TypeError, ValueError) as err:
+                    raise ValueError(
+                        f"Failed to parse column {col} as numbers for add_fromtable()"
+                    ) from err
 
         if dframe[sgcolname].min() > 0.0:
             raise ValueError("sg must start at zero")
