@@ -276,6 +276,23 @@ def test_init_with_swlheight():
     assert gaswater.swcr == 0.3
     assert "swcr=0.3" in gaswater.SWFN()
 
+    # Test error message for missing swirr when swlheight is asked for:
+    with pytest.raises(
+        ValueError, match="Can't initialize from SWLHEIGHT without sufficient simple-J"
+    ):
+        pyscal_factory.create_water_oil(
+            dict(
+                swlheight=200,
+                nw=1,
+                now=1,
+                a=1,
+                b=-2,
+                poro_ref=0.2,
+                perm_ref=100,
+                drho=200,
+            )
+        )
+
 
 def test_relative_swcr():
     """swcr can be initialized relative to swl
@@ -573,6 +590,25 @@ def test_load_relperm_df(tmpdir):
         PyscalFactory.load_relperm_df("dummy.txt")
 
 
+def test_many_nans():
+    """Excel or oocalc sometimes saves a xlsx file that gives all NaN rows and
+    all-NaN columns, maybe some column setting that triggers Pandas to load
+    them as actual columns/rows.
+
+    Ensure we handle extra Nans in both directions"""
+    nanframe = pd.DataFrame(
+        [
+            {"SATNUM": 1, "nw": 2, "now": 2, "Unnamed: 15": np.nan},
+            {"SATNUM": np.nan, "nw": np.nan, "now": np.nan, "Unnamed: 15": np.nan},
+        ]
+    )
+    wateroil_list = PyscalFactory.create_pyscal_list(
+        PyscalFactory.load_relperm_df(nanframe)
+    )
+    assert len(wateroil_list) == 1
+    sat_table_str_ok(wateroil_list.SWOF())
+
+
 def test_xls_factory():
     """Test/demonstrate how to go from data in an excel row to pyscal objects
 
